==> pulumi-azure-native-kotlin-2.37.0.0-sources.jar: com/pulumi/azurenative/app/kotlin/outputs/ScaleRuleResponse.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.app.kotlin.outputs

import kotlin.String
import kotlin.Suppress

/**
 * Container App container scaling rule.
 * @property azureQueue Azure Queue based scaling.
 * @property custom Custom scale rule.
 * @property http HTTP requests based scaling.
 * @property name Scale Rule Name
 * @property tcp Tcp requests based scaling.
 */
public data class ScaleRuleResponse(
    public val azureQueue: QueueScaleRuleResponse? = null,
    public val custom: CustomScaleRuleResponse? = null,
    public val http: HttpScaleRuleResponse? = null,
    public val name: String? = null,
    public val tcp: TcpScaleRuleResponse? = null,
) {
    public companion object {
        public fun toKotlin(javaType: com.pulumi.azurenative.app.outputs.ScaleRuleResponse):
            ScaleRuleResponse = ScaleRuleResponse(
            azureQueue = javaType.azureQueue().map({ args0 ->
                args0.let({ args0 ->
                    com.pulumi.azurenative.app.kotlin.outputs.QueueScaleRuleResponse.Companion.toKotlin(args0)
                })
            }).orElse(null),
            custom = javaType.custom().map({ args0 ->
                args0.let({ args0 ->
                    com.pulumi.azurenative.app.kotlin.outputs.CustomScaleRuleResponse.Companion.toKotlin(args0)
                })
            }).orElse(null),
            http = javaType.http().map({ args0 ->
                args0.let({ args0 ->
                    com.pulumi.azurenative.app.kotlin.outputs.HttpScaleRuleResponse.Companion.toKotlin(args0)
                })
            }).orElse(null),
            name = javaType.name().map({ args0 -> args0 }).orElse(null),
            tcp = javaType.tcp().map({ args0 ->
                args0.let({ args0 ->
                    com.pulumi.azurenative.app.kotlin.outputs.TcpScaleRuleResponse.Companion.toKotlin(args0)
                })
            }).orElse(null),
        )
    }
}

==> pulumi-azure-native-kotlin-2.44.1.0-sources.jar: com/pulumi/azurenative/app/kotlin/outputs/ScaleRuleResponse.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.app.kotlin.outputs

import kotlin.String
import kotlin.Suppress

/**
 * Container App container scaling rule.
 * @property azureQueue Azure Queue based scaling.
 * @property custom Custom scale rule.
 * @property http HTTP requests based scaling.
 * @property name Scale Rule Name
 * @property tcp Tcp requests based scaling.
 */
public data class ScaleRuleResponse(
    public val azureQueue: QueueScaleRuleResponse? = null,
    public val custom: CustomScaleRuleResponse? = null,
    public val http: HttpScaleRuleResponse? = null,
    public val name: String? = null,
    public val tcp: TcpScaleRuleResponse? = null,
) {
    public companion object {
        public fun toKotlin(javaType: com.pulumi.azurenative.app.outputs.ScaleRuleResponse): ScaleRuleResponse = ScaleRuleResponse(
            azureQueue = javaType.azureQueue().map({ args0 ->
                args0.let({ args0 ->
                    com.pulumi.azurenative.app.kotlin.outputs.QueueScaleRuleResponse.Companion.toKotlin(args0)
                })
            }).orElse(null),
            custom = javaType.custom().map({ args0 ->
                args0.let({ args0 ->
                    com.pulumi.azurenative.app.kotlin.outputs.CustomScaleRuleResponse.Companion.toKotlin(args0)
                })
            }).orElse(null),
            http = javaType.http().map({ args0 ->
                args0.let({ args0 ->
                    com.pulumi.azurenative.app.kotlin.outputs.HttpScaleRuleResponse.Companion.toKotlin(args0)
                })
            }).orElse(null),
            name = javaType.name().map({ args0 -> args0 }).orElse(null),
            tcp = javaType.tcp().map({ args0 ->
                args0.let({ args0 ->
                    com.pulumi.azurenative.app.kotlin.outputs.TcpScaleRuleResponse.Companion.toKotlin(args0)
                })
            }).orElse(null),
        )
    }
}
